#ifndef Datenbank_H
#define Datenbank_H

#include <sql.h>
#include <Text.h>
#include <Array.h>
#include <InitDatei.h>

using namespace Framework;
using namespace sql;

namespace Admin_Recht
{
	const int ISStarten = 20;
	const int ISBeenden = 21;
	const int ISPausieren = 22;
	const int ISMCChange = 23;
}

struct AHDaten;
class InformationServer;

class ISDatenbank : public virtual ReferenceCounter
{
private:
	Datenbank* datenbank;
	CRITICAL_SECTION cs;

public:
	// Konstruktor
	ISDatenbank(InitDatei* zIni);
	// Destruktor
	~ISDatenbank();
	// nicht constant
	void lock();
	void unlock();
	int istAdministrator(const char* name, const char* passwort);
	bool adminHatRecht(int id, int recht);
	bool proveKlient(int num, int sNum);
	Text* getKlientKey(int cId);
	void unregisterKlient(int num, int sNum);
	bool setServerStatus(int id, int status);
	bool setMaxClients(int id, int maxC);
	bool serverIstNichtPausiert(int id);
	Text* getInformationsText(char* typ);
	bool istSpielErlaubt(int spielId);
	bool istKarteErlaubt(int karteId);
	Text* getAccountRufName(int accountId);
	int getAccountId(const char* rufName);
	Array< int >* getAccountSpielStatistik(int accountId, int spielId);
	int getAccountKarteSpiele(int accountId, int karteId);
	int getAccountKarteSpieleGewonnen(int accountId, int karteId);
	Text* getKarteName(int karteId);
	Text* getSpielName(int spielId);
	Text* getChatroomName(int chatroomId);
	int getChatroomId(const char* name);
	int getSpielId(int karteId);
	int getSpielId(const char* name);
	int getKarteId(const char* name);
	int getGruppenKarteId(int gruppeId);
	int getGruppeAdminId(int gruppeId);
	int getSpielerPunkte(int spielId, int accountId);
	Array< int >* getAccountSpielArtListe(int cId);
	int getNeusteSpielVersion(int spielId);
	int getKupfer(int cId);
	int getDateiGruppeVonSpiel(int sId);
	Text* getDateiGruppePfad(int dgId);
	Array< int >* getAccountKarteListe(int cId, int kId);
	bool hatAccountKarte(int account, int karte);
	bool hatAccountSpiel(int account, int spiel);
	int getDateiGruppeVonPfad(const char* pfad);
	int getNeusteDateiGruppe(int dg);
	bool getGruppeSpielerAdd(int gruppeId);
	Result getSpielerListe(const char* suche, int* seite, int* maxSeite, int sortStalte, bool backwords);
	bool getSpielerAktivity(int accountId, RCArray< Text >* datum, Array< double >* stOnline, Array< double >* stGespielt,
		Array< int >* anzSpiele, Array< int >* anzGewonnen);
	int getOnlineSeconds(int accountId, const char* beg, const char* end);
	int getGespieltSeconds(int accountId, const char* beg, const char* end);
	int getGespieltSpiele(int accountId, const char* beg, const char* end);
	int getGewonnenSpiele(int accountId, const  char* beg, const char* end);
	Array< int >* getAccountKarteGespieltListe(int accountId, int spielArt);
	Array< int >* getAccountSpielGespieltListe(int accountId);
	Result getSpielPartnerListe(int accountId);
	Result getSpielStatistikListe(int accountId, int* seite, int* maxSeite, int sortStalte, bool backwords);
	AHDaten* getSpielHistorie(int accountId, InformationServer* is);
	bool getHistorieServerPortIp(int clientId, int spielId, int* port, Text* ip);
	bool hatKlientRecht(int kId, int recht);
	Result getKartenListe(int kId, const char* suchFilter, char sortSpalte, char sortRichtung);
	bool getEditorServerPortIp(int clientId, int karteId, int* port, Text* ip);
	bool getKartenServerPortIp(int clientId, int karteId, int* port, Text* ip);
	// constant
	Text* getLetzterFehler() const;
};

#endif